## Apis mellifera abundance ##

#LIBRARIES
library(dplyr)
library(ggplot2)
library(ggpubr)
library(glmmTMB)
library(DHARMa)
library(ggeffects)


#DATA
### abundance - data from Leguizamon et al. 2021 Apidologie - data 2018 ###
abund.leguizamon <- read.table(file = "datos_leguizamon_et_al.csv", sep=",", header=T)

#### abundance of apis - visitor censuses ###
visits <- read.table(file = "censos_visitas_apis.csv", sep=";", header=T)


#DATA TRANSFORMATION

#dummy variable - leguizamon

with_apis_l <- abund.leguizamon$codigo.i == "api.mel"
without_apis_l <-abund.leguizamon$codigo.i != "api.mel"

new_vector_l <- rep(NA, length(abund.leguizamon$codigo.i))

new_vector_l[with_apis_l] <- 1
new_vector_l[without_apis_l] <- 0

abund.leguizamon$dummy <- new_vector_l


#dummy variable. visits

with_apis <- visits$polinizador == "api.mel"
without_apis <- visits$polinizador != "api.mel"

new_vector <- rep(NA, length(visits$polinizador))

new_vector[with_apis] <- 1
new_vector[without_apis] <- 0

visits$tiempo <- rep(5, length(visits$polinizador))

visits$dummy <- new_vector

#abundance

abundance.apis.2018 <- abund.leguizamon %>% group_by(colmena, distancia, bandeja) %>% 
  summarise(no.apis=sum(dummy)) 


apis.visits <- visits  %>% group_by(sitio, distancia, no.de.censo, tiempo) %>% 
  summarise(no.apis=sum(dummy))

abundance.apis.visits <- apis.visits %>% group_by(sitio, distancia) %>%
  summarise(abun.apis=sum(no.apis))

#DATA ANALYSIS
#abundance 1

m1 <- glmmTMB(no.apis ~ distancia + (1|colmena), data=abundance.apis.2018, family="poisson")

simulationOutput <- simulateResiduals(fittedModel = m1, plot = F)
plot(simulationOutput)

testDispersion(m1)
#no dispersion

summary(m1)

#abundance 2


m2 <- glmmTMB(abun.apis ~ distancia + (1|sitio), data=abundance.apis.visits, family="poisson")

simulationOutput <- simulateResiduals(fittedModel = m2, plot = F)
plot(simulationOutput)

testDispersion(m2)
#no dispersion

summary(m2)

#TABLE
table_1<- tab_model(m1, m2, transform=NULL, show.ci=0.95, show.r2  = F, show.aic =T, string.est="Estimates")

confint(m1)
confint(m2)

#PLOT
abundance.2018.p <-ggpredict(m1, terms = c("distancia"),ci.lvl = 0.95)

plot.abundance.2018 <- ggplot(data=NULL, aes(x=abundance.apis.2018$distancia, y=abundance.apis.2018$no.apis)) +
  geom_jitter(aes(x = as.factor(abundance.apis.2018$distancia), y = abundance.apis.2018$no.apis), width=0.2, alpha=0.5, colour="#009ACD") +
  geom_pointrange(data=abundance.2018.p, aes(x =as.factor(x), y=predicted, ymin = conf.low, ymax = conf.high), position=position_dodge(0.7), size=0.3) +
  labs(title = " ", x="Distance", y="Abundance") +
  theme_classic()


abundance.2019.p <-ggpredict(m2, terms = c("distancia"),ci.lvl = 0.95)

plot.abundance.2019 <- ggplot(data=NULL, aes(x=abundance.apis.visits$distancia, y=abundance.apis.visits$abun.apis)) +
  geom_jitter(aes(x=as.factor(abundance.apis.visits$distancia), y=abundance.apis.visits$abun.apis), width=0.2, alpha=0.5, colour="#009ACD") +
  geom_pointrange(data=abundance.2019.p, aes(x =as.factor(x), y=predicted, ymin = conf.low, ymax = conf.high), position=position_dodge(0.7), size=0.3) +
  labs(title = " ", x="Distance", y="Abundance") +
  theme_classic()


apis.mel <- ggarrange(plot.abundance.2018, plot.abundance.2019 , labels = c("A", "B"))
annotate_figure(apis.mel,
                top = text_grob("Apis mellifera", color = "black", face = "italic", size = 15))

